aboutsummaryrefslogtreecommitdiff
path: root/lib/transfer.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/transfer.c')
-rw-r--r--lib/transfer.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/lib/transfer.c b/lib/transfer.c
index 10a3f87dc..f8d0af87b 100644
--- a/lib/transfer.c
+++ b/lib/transfer.c
@@ -1792,9 +1792,11 @@ Transfer(struct connectdata *conn)
struct Curl_transfer_keeper *k = &data->reqdata.keep;
bool done=FALSE;
- if(!(conn->protocol & PROT_FILE)) {
- /* Only do this if we are not transferring FILE:, since the file: treatment
- is different*/
+ if(!(conn->protocol & (PROT_FILE|PROT_TFTP))) {
+ /* Only do this if we are not transferring FILE or TFTP, since those
+ transfers are treated differently. They do their entire transfers in
+ the DO function and just returns from this. That is ugly indeed.
+ */
Curl_readwrite_init(conn);
Curl_pre_readwrite(conn);
}